Trademarks
==========

The following trademarks appear in resqpy source code and/or diagnostic messages.

* **RESQML** is a trademark of the Energistics Consortium
* **Nexus** is a registered trademark of the Halliburton Company
* **RMS** and **ROXAR** are registered trademarks of Roxar Software Solutions AS, an Emerson company
